package main

import (
	"flag"
	"fmt"
	"git.swzry.com/zry/afero2webdav/afero2webdav"
	"github.com/gin-gonic/gin"
	"github.com/spf13/afero"
	"golang.org/x/net/webdav"
	"net/http"
	"strings"
)

var flagHelp bool
var flagServPath string
var flagBindAddr string

func main() {
	flag.BoolVar(&flagHelp, "h", false, "print help")
	flag.StringVar(&flagServPath, "p", ".", "path to serve")
	flag.StringVar(&flagBindAddr, "b", ":8821", "bind address")
	flag.Parse()
	if flagHelp {
		flag.PrintDefaults()
		return
	}
	basefs := afero.NewOsFs()
	bpfs := afero.NewBasePathFs(basefs, flagServPath)
	wfs := afero2webdav.NewAfero2Webdav(bpfs)
	hdl := &webdav.Handler{
		Prefix:     "/",
		FileSystem: wfs,
		LockSystem: webdav.NewMemLS(),
		Logger: func(request *http.Request, err error) {
			if err != nil {
				fmt.Println("[webdav-error] error: ", err)
			}
		},
	}
	websvr := gin.Default()
	websvr.Use(gin.Logger())
	websvr.Use(func(c *gin.Context) {
		if strings.HasPrefix(c.Request.URL.Path, hdl.Prefix) {
			c.Status(200)
			hdl.ServeHTTP(c.Writer, c.Request)
			c.Abort()
		}
	})
	err := websvr.Run(flagBindAddr)
	if err != nil {
		fmt.Println("error in http server: ", err)
		return
	}
}
